isInstantaneous property
bool
get
isInstantaneous
Whether the reading is a point rather than an interval.
Implementation
bool get isInstantaneous => start == end;
Whether the reading is a point rather than an interval.
bool get isInstantaneous => start == end;