VitalsPlatformException class final

Anything the platform reported that does not map to a specific case.

Inheritance

Constructors

VitalsPlatformException(String message, {String? code})
Creates the exception with the raw platform code.
const

Properties

code String?
The platform's own error code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
What went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited