VitalsPlatformException class final
Anything the platform reported that does not map to a specific case.
- Inheritance
-
- Object
- VitalsException
- VitalsPlatformException
Constructors
- VitalsPlatformException(String message, {String? code})
-
Creates the exception with the raw platform
code.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited